@@ -1,6 +1,6 @@
 # ABSTRACT: Get information for different currencies
 package Data::MoneyCurrency;
-$Data::MoneyCurrency::VERSION = '0.22';
+$Data::MoneyCurrency::VERSION = '0.23';
 use strict;
 use warnings;
 use utf8;
@@ -328,7 +328,7 @@ my $rh_currencies_for_country = {
     uz   => ['uzs'],
     va   => ['eur'],
     vc   => ['xcd'],
-    ve   => ['vef'],
+    ve   => ['ves'],
     vg   => ['usd'],
     vi   => ['usd'],
     vn   => ['vnd'],
@@ -371,7 +371,7 @@ Data::MoneyCurrency - Get information for different currencies
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -452,7 +452,7 @@ edf <cpan@opencagedata.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by OpenCage GmbH.
+This software is copyright (c) 2022 by OpenCage GmbH.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
