@@ -1,6 +1,3 @@
-require "coveralls"
-Coveralls.wear!
-
 $LOAD_PATH.unshift File.dirname(__FILE__)
 require "rspec"
 require "money"
